--- Odometer - it does what it says
--- Created by ARF 11/2015

declare("odometer",{
	version = 1.1,
	--thrust = 0,
	distance = 0,
	readout = iup.label{title="Shouldn't see me."},
	gui = iup.hbox{},
})

local GGT = gkmisc.GetGameTime
local DT = gkmisc.DiffTime

local samples = {0,0,0,0}
local a, s = 0,0 
local t = GGT()
local hudsetspeed = HUD.setspeed

function sum(t)
	local sum = 0
	for k, v in ipairs(t) do
		sum = sum + v 
	end
	return sum
end

-- HUD hook function that does all the work.
function odometer:setspeed(speed)
	-- Remember: self here isn't odometer, it's HUD.
	local dt = math.abs(DT(GGT(),t)/1000)
	odometer.distance = odometer.distance + speed*dt
	
	a = math.abs(s-speed)/dt
	table.insert(samples,a)
	--odometer.thrust = sum(samples)/#samples 
	local readout = odometer.readout
	readout.title = string.format("%0.2fkm", odometer.distance / 1000) 
	hudsetspeed(HUD, speed)
	t = GGT()
	s = speed
	table.remove(samples,1)
end

-- Create HUD readout
function odometer:create_display()
	local rightmargin = gkinterface.GetXResolution() * 0.20
	self.readout = iup.label{title = "0.00km", size=175*HUD_SCALE, 
		font=Font.H4*font_HUD_SCALE, alignment="ARIGHT"}

	self.gui = iup.hbox{
		iup.fill{},iup.vbox{
			iup.fill{},
			self.readout,
			iup.fill{size = 25},
		}, 
		iup.fill{size = rightmargin},
	}
end

function odometer:hook()
	hudsetspeed = HUD.setspeed
	HUD.setspeed = odometer.setspeed 
end

function odometer:show_display()
	print("show display")
	iup.Append(HUD.pluginlayer, self.gui)
	iup.Refresh(self.gui)
end

function odometer:hide_display()
	print("hide display")
	iup.Detach(self.gui)
end

function odometer:init()
	odometer:hook()
	odometer:create_display()
	odometer:show_display()
end
-- default to on
odometer:init()

-- User commands
function odometer.cmd(data, args)
	if args[1] then 
		if args[1] == "reset" then
			odometer.distance = 0 
		elseif args[1] == "show" then
			odometer:show_display()
		elseif args[1] == "hide" then
			odometer:hide_display()
		elseif args[1] == "help" then
			print("odometer commands: reset, show, hide")
		end
	end
end

RegisterUserCommand("odometer", odometer.cmd)

-- Event handlers
function odometer.rHUDxscale(event, data)
	odometer:init()
end

RegisterEvent(odometer, 'rHUDxscale')
